# Seaplane Python SDK

A library for developing and deploying your applications to the Seaplane Infrastructure.

See the [Seaplane Quick-Start Guide](https://developers.seaplane.io/docs/quick-start) for
details about how to get going with building and deploying Seaplane applications.

## License

Licensed under the Apache License, Version 2.0, [LICENSE]. Copyright 2022 Seaplane IO, Inc.

[//]: # (Links)

[LICENSE]: https://github.com/seaplane-io/seaplane/blob/main/LICENSE
